scieloh5m5
----------

Biblioteca para fornecer indicadores h5m5 do Google Scholar dos periódicos SciELO.

Build Status
------------

.. image:: https://travis-ci.org/scieloorg/scieloh5m5.svg?branch=master
    :target: https://travis-ci.org/scieloorg/scieloh5m5
